Learn R Programming

glossr (version 0.8.0)

config_from_file: Override configuration with a YAML file

Description

Read configuration from a YAML file to provide instructions for styling and PDF- or Word-specific options.

Usage

config_from_file(filename)

Value

Invisibly, the contents of the configuration file that passed validation.

Arguments

filename

Path to the YAML configuration file, e.g. "glossr-config.yaml".

Examples

Run this code
config_file <- system.file("extdata/glossr-config.yml", package="glossr")
config_from_file(config_file)
print_config()

Run the code above in your browser using DataLab