| gloss_render | R Documentation |
These functions are output-specific and can be used to check the specific output
of certain calls, but are not meant to be used in an R Markdown file. Instead,
use as_gloss() or gloss_df().
gloss_pdf(gloss)
gloss_html(gloss, numbering = TRUE)
gloss_tooltip(gloss, numbering = TRUE)
gloss_leipzig(gloss, numbering = TRUE)
gloss_word(gloss, numbering = TRUE)
gloss |
Object of class |
numbering |
Whether the gloss should be numbered (in HTML and Word). |
Object of class gloss.
gloss_pdf(): Render in PDF
gloss_html(): Render in HTML
gloss_tooltip(): Tooltip rendering for HTML
gloss_leipzig(): Leipzig.js engine
gloss_word(): Render in Word
ex_sp <- "Un ejemplo en espaƱol"
ex_gloss <- "DET.M.SG example in Spanish"
ex_trans <- "An example in Spanish"
my_gloss <- new_gloss_data(list(ex_sp, ex_gloss), translation = ex_trans, label="ex1")
gloss_pdf(my_gloss)
gloss_html(my_gloss)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.