Learn R Programming

glossr (version 0.8.0)

glossr-package: glossr: Use interlinear glosses in R Markdown

Description

Read examples with interlinear glosses from files or from text and print them in a way compatible with both Latex and HTML outputs.

Arguments

Author

Maintainer: Mariana Montes montesmariana@gmail.com (ORCID)

Other contributors:

  • Benjamin Chauvette (Author of included leipzig.js library) [copyright holder]

See Also