| new_gloss | R Documentation |
The gloss class contains how a gloss will be printed and its original input
(Object of class gloss_data) as data attribute.
It also has a knitr::knit_print() method for rendering in R Markdown (and Quarto).
new_gloss(input, output)
input |
A |
output |
How the gloss must be printed, depending on the output. |
Object of class gloss.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.