powered by
Read configuration from a YAML file to provide instructions for styling and PDF- or Word-specific options.
config_from_file(filename)
Invisibly, the contents of the configuration file that passed validation.
Path to the YAML configuration file, e.g. "glossr-config.yaml".
config_file <- system.file("extdata/glossr-config.yml", package="glossr") config_from_file(config_file) print_config()
Run the code above in your browser using DataLab