gloss_list: Sublist glosses
Description
Takes a series of glosses from gloss_render()
and puts them in a list within one example for PDF output.
Usage
gloss_list(glist, listlabel = NULL)
Value
Character vector including the frame for a list of glosses.
Arguments
- glist
Concatenation of gloss objects, e.g.
as output of gloss_df().
- listlabel
Label for the full list (optional)