The gloss class contains how a gloss will be printed and its original input
(Object of class gloss_data) as data attribute.
It also has a knitr::knit_print() method for rendering in R Markdown (and Quarto).
Usage
new_gloss(input, output)
Value
Object of class gloss.
Arguments
input
A gloss_data object.
output
How the gloss must be printed, depending on the output.